@@ -35,20 +35,12 @@ RETRY_BACKOFF_FACTOR = 0.8
 # API Paths and API Extra Parameters
 #
 API_PATH = {
-    'scopes': 'api/scopes.json',
-    'scope': 'api/scopes/{scope_id}.json',
     'activities': 'api/activities.json',
     'activity': 'api/activities/{activity_id}.json',
     'activity_export': 'api/activities/{activity_id}/export',
     'activity_move': 'api/activities/{activity_id}/move_activity',
     'activities_bulk_clone': 'api/activities/bulk_clone',
     'activities_bulk_update': 'api/activities/bulk_update',
-    'parts': 'api/parts.json',
-    'part': 'api/parts/{part_id}.json',
-    'properties': 'api/properties.json',
-    'property': 'api/properties/{property_id}.json',
-    'property_upload': 'api/properties/{property_id}/upload',
-    'property_download': 'api/properties/{property_id}/download',
     'widgets_config': 'api/widget_config.json',
     'widget_config': 'api/widget_config/{widget_config_id}.json',
     'services': 'api/services.json',
@@ -71,31 +63,31 @@ API_PATH = {
     'associations': 'api/associations.json',
 
     # PIM3
-    'scope2': 'api/v3/scopes/{scope_id}.json',
-    'scope2_add_member': 'api/v3/scopes/{scope_id}/add_member',
-    'scope2_remove_member': 'api/v3/scopes/{scope_id}/remove_member',
-    'scope2_add_manager': 'api/v3/scopes/{scope_id}/add_manager',
-    'scope2_remove_manager': 'api/v3/scopes/{scope_id}/remove_manager',
-    'scope2_add_leadmember': 'api/v3/scopes/{scope_id}/add_leadmember',
-    'scope2_remove_leadmember': 'api/v3/scopes/{scope_id}/remove_leadmember',
-    'scopes2': 'api/v3/scopes.json',
-    'scopes2_clone': 'api/v3/scopes/clone',
-    'parts2': 'api/v3/parts.json',
-    'parts2_new_instance': 'api/v3/parts/new_instance',
-    'parts2_create_child_model': 'api/v3/parts/create_child_model',
-    'parts2_create_proxy_model': 'api/v3/parts/create_proxy_model',
-    'parts2_clone_model': 'api/v3/parts/clone_model',
-    'parts2_clone_instance': 'api/v3/parts/clone_instance',
-    'parts2_bulk_create': '/api/v3/parts/bulk_create_part_instances',
-    'parts2_bulk_delete': '/api/v3/parts/bulk_delete_part_instances',
-    'parts2_export': 'api/v3/parts/export',
-    'part2': 'api/v3/parts/{part_id}.json',
-    'properties2': 'api/v3/properties.json',
-    'properties2_bulk_update': 'api/v3/properties/bulk_update',
-    'properties2_create_model': 'api/v3/properties/create_model',
-    'property2': 'api/v3/properties/{property_id}.json',
-    'property2_upload': 'api/v3/properties/{property_id}/upload',
-    'property2_download': 'api/v3/properties/{property_id}/download',
+    'scope': 'api/v3/scopes/{scope_id}.json',
+    'scope_add_member': 'api/v3/scopes/{scope_id}/add_member',
+    'scope_remove_member': 'api/v3/scopes/{scope_id}/remove_member',
+    'scope_add_manager': 'api/v3/scopes/{scope_id}/add_manager',
+    'scope_remove_manager': 'api/v3/scopes/{scope_id}/remove_manager',
+    'scope_add_leadmember': 'api/v3/scopes/{scope_id}/add_leadmember',
+    'scope_remove_leadmember': 'api/v3/scopes/{scope_id}/remove_leadmember',
+    'scopes': 'api/v3/scopes.json',
+    'scopes_clone': 'api/v3/scopes/clone',
+    'parts': 'api/v3/parts.json',
+    'parts_new_instance': 'api/v3/parts/new_instance',
+    'parts_create_child_model': 'api/v3/parts/create_child_model',
+    'parts_create_proxy_model': 'api/v3/parts/create_proxy_model',
+    'parts_clone_model': 'api/v3/parts/clone_model',
+    'parts_clone_instance': 'api/v3/parts/clone_instance',
+    'parts_bulk_create': '/api/v3/parts/bulk_create_part_instances',
+    'parts_bulk_delete': '/api/v3/parts/bulk_delete_part_instances',
+    'parts_export': 'api/v3/parts/export',
+    'part': 'api/v3/parts/{part_id}.json',
+    'properties': 'api/v3/properties.json',
+    'properties_bulk_update': 'api/v3/properties/bulk_update',
+    'properties_create_model': 'api/v3/properties/create_model',
+    'property': 'api/v3/properties/{property_id}.json',
+    'property_upload': 'api/v3/properties/{property_id}/upload',
+    'property_download': 'api/v3/properties/{property_id}/download',
     'widgets': 'api/widgets.json',
     'widget': 'api/widgets/{widget_id}.json',
     'widget_clear_associations': 'api/widgets/{widget_id}/clear_associations.json',
@@ -130,30 +122,30 @@ API_EXTRA_PARAMS = {
         ['id', 'text', 'icon', 'is_active', 'active_from', 'active_until', 'url', 'created_at', 'updated_at'])},
     'banners': {'fields': ",".join(
         ['id', 'text', 'icon', 'is_active', 'active_from', 'active_until', 'url', 'created_at', 'updated_at'])},
-    'scope2': {'fields': ",".join(
+    'scope': {'fields': ",".join(
         ['id', 'name', 'ref', 'text', 'created_at', 'updated_at', 'start_date', 'due_date', 'status', 'category',
          'progress', 'members', 'team', 'tags', 'scope_options', 'team_id_name',
          'workflow_root_id', 'catalog_root_id', 'app_root_id',
          'product_model_id', 'product_instance_id', 'catalog_model_id', 'catalog_instance_id',
          ])},
-    'scopes2': {'fields': ",".join(
+    'scopes': {'fields': ",".join(
         ['id', 'name', 'ref', 'text', 'created_at', 'updated_at', 'start_date', 'due_date', 'status', 'category',
          'progress', 'members', 'team', 'tags', 'scope_options', 'team_id_name',
          'workflow_root_id', 'catalog_root_id', 'app_root_id',
          'product_model_id', 'product_instance_id', 'catalog_model_id', 'catalog_instance_id',
          ])},
-    'part2': {'fields': ",".join(
+    'part': {'fields': ",".join(
         ['id', 'name', 'ref', 'description', 'created_at', 'updated_at', 'properties', 'category', 'classification',
          'parent_id', 'multiplicity', 'value_options', 'property_type', 'value', 'output', 'order',
          'part_id', 'scope_id', 'model_id', 'proxy_source_id_name', 'unit'])},
-    'parts2': {'fields': ",".join(
+    'parts': {'fields': ",".join(
         ['id', 'name', 'ref', 'description', 'created_at', 'updated_at', 'properties', 'category', 'classification',
          'parent_id', 'multiplicity', 'value_options', 'property_type', 'value', 'output', 'order',
          'part_id', 'scope_id', 'model_id', 'proxy_source_id_name', 'unit'])},
-    'properties2': {'fields': ",".join(
+    'properties': {'fields': ",".join(
         ['id', 'name', 'ref', 'created_at', 'updated_at', 'model_id', 'part_id', 'order', 'scope_id', 'category',
          'property_type', 'value', 'value_options', 'output', 'description', 'unit'])},
-    'property2': {'fields': ",".join(
+    'property': {'fields': ",".join(
         ['id', 'name', 'ref', 'created_at', 'updated_at', 'model_id', 'part_id', 'order', 'scope_id', 'category',
          'property_type', 'value', 'value_options', 'output', 'description', 'unit'])},
     'service': {'fields': ",".join(
