@@ -1,5 +1,5 @@
 import warnings
-from typing import Iterable, Union, AnyStr, Optional, Text, Dict, List, Any
+from typing import Iterable, Union, Optional, Text, Dict, List, Any
 
 from pykechain.enums import SortTable, WidgetTypes, ShowColumnTypes, ScopeWidgetColumnTypes, \
     ProgressBarColors, PropertyType, CardWidgetImageValue, CardWidgetLinkValue, LinkTargets, ImageFitValue, \
@@ -21,8 +21,7 @@ class WidgetsManager(Iterable):
 
     def __init__(self,
                  widgets: Iterable[Widget],
-                 activity: Union['Activity2', AnyStr],
-                 client: Optional['Client'] = None,
+                 activity: 'Activity',
                  **kwargs) -> None:
         """Construct a Widget Manager from a list of widgets.
 
@@ -31,10 +30,8 @@ class WidgetsManager(Iterable):
 
         :param widgets: list of widgets.
         :type widgets: List[Widget]
-        :param activity: an :class:`Activity` object or an activity UUID
-        :type activity: basestring or None
-        :param client: (O) if the activity was provided as a UUID, also provide a :class:`Client` object.
-        :type client: `Client` or None
+        :param activity: an :class:`Activity` object
+        :type activity: Activity
         :param kwargs: additional keyword arguments
         :type kwargs: dict or None
         :returns: None
@@ -43,35 +40,27 @@ class WidgetsManager(Iterable):
         self._widgets = list(widgets)  # type: List[Widget]
         for widget in self._widgets:
             widget.manager = self
-        from pykechain.models import Activity2
-        from pykechain import Client
-        if isinstance(activity, Activity2):
-            self._activity_id = activity.id
-            self._client = activity._client  # type: Client
-        elif isinstance(activity, str) and client is not None:
-            self._activity_id = activity
-            self._client = client  # type: Client
-        else:
-            raise IllegalArgumentError("The `WidgetsManager` should be provided either an :class:`Activity` or "
-                                       "an activity uuid and a `Client` to function properly.")
 
-        self._iter = iter(self._widgets)
+        from pykechain.models import Activity
+        from pykechain import Client
+
+        if not isinstance(activity, Activity):
+            raise IllegalArgumentError(
+                "The `WidgetsManager` should be provided a :class:`Activity` to function properly.")
+
+        self.activity = activity  # type: Activity
+        self._activity_id = activity.id
+        self._client = activity._client  # type: Client
 
     def __repr__(self) -> Text:  # pragma: no cover
         return "<pyke {} object {} widgets>".format(self.__class__.__name__, self.__len__())
 
     def __iter__(self):
-        return self
+        return iter(self._widgets)
 
     def __len__(self) -> int:
         return len(self._widgets)
 
-    def __next__(self) -> Widget:
-        # py3.4 and up style next
-        return next(self._iter)
-
-    next = __next__  # py2.7 alias
-
     def __getitem__(self, key: Union[int, str, Widget]) -> Widget:
         """Widget from the list of widgets based on index, uuid, title or ref.
 
@@ -109,7 +98,7 @@ class WidgetsManager(Iterable):
         """
         # Insert the current widget
         for widget in widgets:
-            widget['activity'] = self._activity_id
+            widget['activity'] = self.activity
 
         return self._client.create_widgets(widgets=widgets)
 
@@ -147,7 +136,7 @@ class WidgetsManager(Iterable):
         if 'parent_widget' in kwargs:
             kwargs['parent'] = kwargs.pop('parent_widget')
 
-        widget = self._client.create_widget(*args, activity=self._activity_id, **kwargs)
+        widget = self._client.create_widget(*args, activity=self.activity, **kwargs)
 
         if kwargs.get('order') is None:
             self._widgets.append(widget)
@@ -157,7 +146,7 @@ class WidgetsManager(Iterable):
 
     def create_configured_widget(
             self,
-            part: 'Part2',
+            part: 'Part',
             all_readable: Optional[bool] = None,
             all_writable: Optional[bool] = None,
             readable_models: Optional[List[Union['AnyProperty', Text]]] = None,
@@ -168,7 +157,7 @@ class WidgetsManager(Iterable):
         Create a widget with configured properties.
 
         :param part: Part to retrieve the properties from if all_readable or all_writable is True.
-        :type part: Part2
+        :type part: Part
         :param all_readable: Selects all the `Properties` of part_model and configures them as readable in the widget
         :type all_readable: bool
         :param all_writable: Selects all the `Properties` of part_model and configures them as writable in the widget
@@ -196,8 +185,8 @@ class WidgetsManager(Iterable):
             **kwargs)
 
     def add_supergrid_widget(self,
-                             part_model: Union['Part2', Text],
-                             parent_instance: Optional[Union['Part2', Text]] = None,
+                             part_model: Union['Part', Text],
+                             parent_instance: Optional[Union['Part', Text]] = None,
                              title: Optional[Union[type(None), Text, bool]] = False,
                              parent_widget: Optional[Union[Widget, Text]] = None,
                              new_instance: Optional[bool] = True,
@@ -283,11 +272,11 @@ class WidgetsManager(Iterable):
         :raises APIError: When the widget could not be created.
         """
         # Check whether the part_model is uuid type or class `Part`
-        part_model = _retrieve_object(obj=part_model, method=self._client.model)  # type: 'Part2'  # noqa
-        parent_instance = _retrieve_object_id(obj=parent_instance)  # type: 'Part2'  # noqa
+        part_model = _retrieve_object(obj=part_model, method=self._client.model)  # type: 'Part'  # noqa
+        parent_instance = _retrieve_object_id(obj=parent_instance)  # type: 'Part'  # noqa
         sort_property_id = _retrieve_object_id(obj=sort_property)
 
-        meta = _initiate_meta(kwargs=kwargs, activity=self._activity_id)
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
         meta.update({
             # grid
             "partModelId": part_model.id,
@@ -313,7 +302,7 @@ class WidgetsManager(Iterable):
         if parent_instance:
             meta['parentInstanceId'] = parent_instance
 
-        meta, title = _set_title(meta, title=title, default_title=part_model.name, **kwargs)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         widget = self.create_configured_widget(
             widget_type=WidgetTypes.SUPERGRID,
@@ -330,8 +319,8 @@ class WidgetsManager(Iterable):
         return widget
 
     def add_filteredgrid_widget(self,
-                                part_model: Union['Part2', Text],
-                                parent_instance: Optional[Union['Part2', Text]] = None,
+                                part_model: Union['Part', Text],
+                                parent_instance: Optional[Union['Part', Text]] = None,
                                 title: Optional[Union[type(None), Text, bool]] = False,
                                 parent_widget: Optional[Union[Widget, Text]] = None,
                                 new_instance: Optional[bool] = True,
@@ -424,7 +413,7 @@ class WidgetsManager(Iterable):
         :param excluded_propmodels: (O) list of properties not shown in the filter pane
         :type excluded_propmodels: list
         :param prefilters: (O) default filters active in the grid, defined as a dict with the following fields:
-            * property_models: list of Properties, defined as Property2 objects or UUIDs
+            * property_models: list of Properties, defined as Property objects or UUIDs
             * values: the pre-filter value for each property to filter on
             * filters_type: the types of filters, either `le`, `ge`, `icontains` or `exact`
         :type prefilters: dict
@@ -436,12 +425,12 @@ class WidgetsManager(Iterable):
         :raises APIError: When the widget could not be created.
         """
         # Check whether the part_model is uuid type or class `Part`
-        part_model = _retrieve_object(obj=part_model, method=self._client.model)  # type: 'Part2'  # noqa
+        part_model = _retrieve_object(obj=part_model, method=self._client.model)  # type: 'Part'  # noqa
         parent_instance_id = _retrieve_object_id(obj=parent_instance)  # type: text_type
         sort_property_id = _retrieve_object_id(obj=sort_property)  # type: text_type
         if not sort_property_id and sort_name:
             sort_property_id = "name"
-        meta = _initiate_meta(kwargs=kwargs, activity=self._activity_id)
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
         if prefilters:
             list_of_prefilters = _check_prefilters(part_model=part_model, prefilters=prefilters)
             prefilters = {'property_value': ','.join(list_of_prefilters) if list_of_prefilters else {}}
@@ -479,7 +468,7 @@ class WidgetsManager(Iterable):
         if parent_instance_id:
             meta['parentInstanceId'] = parent_instance_id
 
-        meta, title = _set_title(meta, title=title, default_title=part_model.name, **kwargs)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         widget = self.create_configured_widget(
             widget_type=WidgetTypes.FILTEREDGRID,
@@ -496,7 +485,7 @@ class WidgetsManager(Iterable):
         return widget
 
     def add_attachmentviewer_widget(self,
-                                    attachment_property: Union[Text, 'AttachmentProperty2'],
+                                    attachment_property: Union[Text, 'AttachmentProperty'],
                                     editable: Optional[bool] = False,
                                     title: Optional[Union[Text, bool]] = False,
                                     parent_widget: Optional[Union[Widget, Text]] = None,
@@ -515,7 +504,7 @@ class WidgetsManager(Iterable):
         :param editable: Whether the attachment can be added, edited or deleted (default: False)
         :type editable: bool
         :param title: A custom title for the script widget
-            * False (default): Script name
+            * False (default): Property name
             * String value: Custom title
             * None: No title
         :type title: bool or basestring or None
@@ -534,8 +523,8 @@ class WidgetsManager(Iterable):
         :raises APIError: When the widget could not be created.
         """
         attachment_property = _retrieve_object(attachment_property,
-                                               method=self._client.property)  # type: 'Property2'
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
+                                               method=self._client.property)  # type: 'Property'
+        meta = _initiate_meta(kwargs, activity=self.activity)
 
         meta.update({
             "propertyInstanceId": attachment_property.id,
@@ -551,7 +540,7 @@ class WidgetsManager(Iterable):
                 warnings.warn('Argument "{}" is no longer supported as input to `add_attachment_viewer`.'.format(
                     deprecated_kw), Warning)
 
-        meta, title = _set_title(meta, title=title, default_title=attachment_property.name, **kwargs)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         if check_type(editable, bool, 'editable'):
             kwargs.update({'writable_models': [attachment_property.model_id]})
@@ -597,7 +586,7 @@ class WidgetsManager(Iterable):
         :raises IllegalArgumentError: when incorrect arguments are provided
         :raises APIError: When the widget could not be created.
         """
-        from pykechain.models import Activity2
+        from pykechain.models import Activity
 
         set_of_expected_keys = {'activityId', 'customText', 'emphasized', 'emphasize', 'isDisabled', 'link'}
         task_buttons = list()
@@ -611,7 +600,7 @@ class WidgetsManager(Iterable):
             if 'activityId' in input_dict:
                 # Check whether the activityId is class `Activity` or UUID
                 activity = input_dict['activityId']
-                if isinstance(activity, Activity2):
+                if isinstance(activity, Activity):
                     button_dict['activityId'] = activity.id
                 elif isinstance(activity, str) and is_uuid(activity):
                     button_dict['activityId'] = activity
@@ -635,7 +624,7 @@ class WidgetsManager(Iterable):
 
             button_dict['isDisabled'] = input_dict.get('isDisabled', False)
 
-        meta = _initiate_meta(kwargs, activity=self._activity_id, ignores=('showHeightValue',))
+        meta = _initiate_meta(kwargs, activity=self.activity, ignores=('showHeightValue',))
         meta['taskButtons'] = task_buttons
         meta['alignment'] = check_enum(alignment, Alignment, 'alignment')
 
@@ -649,7 +638,7 @@ class WidgetsManager(Iterable):
         return widget
 
     def add_propertygrid_widget(self,
-                                part_instance: Union['Part2', Text],
+                                part_instance: Union['Part', Text],
                                 title: Optional[Union[Text, bool]] = False,
                                 max_height: Optional[int] = None,
                                 show_headers: Optional[bool] = True,
@@ -696,7 +685,7 @@ class WidgetsManager(Iterable):
         :raises APIError: When the widget could not be created.
         """
         # Check whether the part_model is uuid type or class `Part`
-        part_instance = _retrieve_object(part_instance, method=self._client.part)  # type: 'Part2'  # noqa: F821
+        part_instance = _retrieve_object(part_instance, method=self._client.part)  # type: 'Part'  # noqa: F821
 
         if not show_columns:
             show_columns = list()
@@ -711,7 +700,7 @@ class WidgetsManager(Iterable):
             else:
                 display_columns[possible_column] = False
 
-        meta = _initiate_meta(kwargs=kwargs, activity=self._activity_id)
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
         meta.update({
             "customHeight": max_height if max_height else None,
             "partInstanceId": part_instance.id,
@@ -719,7 +708,7 @@ class WidgetsManager(Iterable):
             "showHeaders": show_headers,
         })
 
-        meta, title = _set_title(meta, title=title, default_title=part_instance.name, **kwargs)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         widget = self.create_configured_widget(
             widget_type=WidgetTypes.PROPERTYGRID,
@@ -778,7 +767,7 @@ class WidgetsManager(Iterable):
         # Check whether the script is uuid type or class `Service`
         service = _retrieve_object(obj=service, method=self._client.service)  # type: 'Service'  # noqa
 
-        meta = _initiate_meta(kwargs=kwargs, activity=self._activity_id)
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
 
         # Add custom button text
         if custom_button_text is False:
@@ -803,7 +792,7 @@ class WidgetsManager(Iterable):
             'showLog': True if download_log else check_type(show_log, bool, 'show_log'),
         })
 
-        meta, title = _set_title(meta, title=title, default_title=service.name, **kwargs)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         widget = self.create_widget(
             widget_type=WidgetTypes.SERVICE,
@@ -841,8 +830,8 @@ class WidgetsManager(Iterable):
         """
         check_text(html, 'html')
 
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=WidgetTypes.HTML, **kwargs)
+        meta = _initiate_meta(kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         meta["htmlContent"] = html
 
@@ -891,8 +880,8 @@ class WidgetsManager(Iterable):
             raise IllegalArgumentError("When using the add_notebook_widget, notebook must be a Service or Service id. "
                                        "Type is: {}".format(type(notebook)))
 
-        meta = _initiate_meta(kwargs=kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=notebook.name, **kwargs)
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         meta.update({
             'serviceId': notebook_id
@@ -921,7 +910,7 @@ class WidgetsManager(Iterable):
                              show_download_pdf: Optional[bool] = False,
                              show_progressbar: Optional[bool] = False,
                              progress_bar: Optional[Dict] = None,
-                             breadcrumb_root: Optional['Activity2'] = None,
+                             breadcrumb_root: Optional['Activity'] = None,
                              **kwargs) -> Widget:
         """
         Add a KE-chain Metapanel to the WidgetManager.
@@ -953,20 +942,20 @@ class WidgetsManager(Iterable):
         :param progress_bar: Progress bar custom settings. Allowed dictionary items `colorNoProgress, showProgressText,
         showProgressText, customHeight, colorInProgress, colorCompleted, colorInProgressBackground`
         :type progress_bar: dict or None
-        :param breadcrumb_root: Activity2 object or UUID to specify the breadcrumb root
-        :type breadcrumb_root: Activity2
+        :param breadcrumb_root: Activity object or UUID to specify the breadcrumb root
+        :type breadcrumb_root: Activity
         :param kwargs: additional keyword arguments to pass
         :return: newly created widget
         :rtype: Widget
         :raises IllegalArgumentError: when incorrect arguments are provided
         :raises APIError: When the widget could not be created.
         """
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
+        meta = _initiate_meta(kwargs, activity=self.activity)
 
         if show_all:
             meta['showAll'] = True
         else:
-            from pykechain.models import Activity2
+            from pykechain.models import Activity
             meta.update(dict(
                 showAll=False,
                 showDueDate=show_due_date,
@@ -983,7 +972,7 @@ class WidgetsManager(Iterable):
                 # if progress=False and Bar=False, both are False
                 showProgress=show_progress and not show_progressbar or show_progress,
                 showProgressBar=show_progressbar and not show_progress,
-                breadcrumbAncestor=check_base(breadcrumb_root, Activity2, 'breadcrumb_root') or None,
+                breadcrumbAncestor=check_base(breadcrumb_root, Activity, 'breadcrumb_root') or None,
             ))
         if progress_bar:
             meta.update(dict(
@@ -1032,7 +1021,7 @@ class WidgetsManager(Iterable):
         :return: newly created widget
         :rtype Widget
         """
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
+        meta = _initiate_meta(kwargs, activity=self.activity)
 
         meta.update(dict(
             colorNoProgress=color_no_progress,
@@ -1068,8 +1057,8 @@ class WidgetsManager(Iterable):
         :raises IllegalArgumentError: when incorrect arguments are provided
         :raises APIError: When the widget could not be created.
         """
-        meta = _initiate_meta(kwargs=kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=WidgetTypes.MULTICOLUMN, **kwargs)
+        meta = _initiate_meta(kwargs=kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         widget = self.create_widget(
             widget_type=WidgetTypes.MULTICOLUMN,
@@ -1155,8 +1144,8 @@ class WidgetsManager(Iterable):
         :raises IllegalArgumentError: when incorrect arguments are provided
         :raises APIError: When the widget could not be created.
         """
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=WidgetTypes.SCOPE, **kwargs)
+        meta = _initiate_meta(kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         check_type(show_all_columns, bool, 'show_all_columns')
 
@@ -1205,13 +1194,16 @@ class WidgetsManager(Iterable):
         )
         return widget
 
-    def add_signature_widget(self,
-                             attachment_property: 'AttachmentProperty2',
-                             title: Optional[Union[bool, Text]] = False,
-                             parent_widget: Optional[Union[Widget, Text]] = None,
-                             custom_button_text: Optional[Union[bool, Text]] = False,
-                             custom_undo_button_text: Optional[Union[bool, Text]] = False,
-                             **kwargs) -> Widget:
+    def add_signature_widget(
+            self,
+            attachment_property: 'AttachmentProperty',
+            title: Optional[Union[bool, Text]] = False,
+            parent_widget: Optional[Union[Widget, Text]] = None,
+            custom_button_text: Optional[Union[bool, Text]] = False,
+            custom_undo_button_text: Optional[Union[bool, Text]] = False,
+            editable: Optional[bool] = True,
+            **kwargs
+    ) -> Widget:
         """
         Add a KE-chain Signature widget to the Widgetmanager and the activity.
 
@@ -1228,6 +1220,8 @@ class WidgetsManager(Iterable):
         :type custom_button_text: bool or basestring
         :param custom_undo_button_text: Custom text for 'Remove signature' button
         :type custom_undo_button_text: bool or basestring
+        :param editable: (optional) if False, creates a viewable, not editable, signature widget (default = True)
+        :type editable: bool
         :param kwargs: additional keyword arguments to pass
         :return: newly created widget
         :rtype: Widget
@@ -1235,9 +1229,10 @@ class WidgetsManager(Iterable):
         :raises APIError: When the widget could not be created.
         """
         attachment_property = _retrieve_object(attachment_property,
-                                               method=self._client.property)  # type: 'AttachmentProperty2'  # noqa
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=attachment_property.name, **kwargs)
+                                               method=self._client.property)  # type: 'AttachmentProperty'  # noqa
+        meta = _initiate_meta(kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
+        check_type(editable, bool, "editable")
 
         # Add custom button text
         if not custom_button_text:
@@ -1268,14 +1263,15 @@ class WidgetsManager(Iterable):
             meta=meta,
             title=title,
             parent=parent_widget,
-            readable_models=[attachment_property.model_id],
+            readable_models=[attachment_property.model_id] if not editable else None,
+            writable_models=[attachment_property.model_id] if editable else None,
             **kwargs,
         )
         return widget
 
     def add_card_widget(self,
-                        image: Optional['AttachmentProperty2'] = None,
-                        title: Optional[Union[type(None), Text, bool]] = None,
+                        image: Optional['AttachmentProperty'] = None,
+                        title: Optional[Union[type(None), Text, bool]] = False,
                         parent_widget: Optional[Union[Widget, Text]] = None,
                         description: Optional[Union[Text, bool]] = None,
                         link: Optional[Union[type(None), Text, bool, KEChainPages]] = None,
@@ -1288,7 +1284,7 @@ class WidgetsManager(Iterable):
 
         The widget will be saved in KE-chain.
 
-        :param image: AttachmentProperty2 providing the source of the image shown in the card widget.
+        :param image: AttachmentProperty providing the source of the image shown in the card widget.
         :param title: A custom title for the card widget
             * False (default): Card name
             * String value: Custom title
@@ -1299,7 +1295,7 @@ class WidgetsManager(Iterable):
             * None: No title
         :param link: Where the card widget refers to. This can be one of the following:
             * None (default): no link
-            * task: another KE-chain task, provided as an Activity2 object or its UUID
+            * task: another KE-chain task, provided as an Activity object or its UUID
             * String value: URL to a webpage
             * KE-chain page: built-in KE-chain page of the current scope
         :param link_value: Overwrite the default link value (obtained from the type of the link)
@@ -1310,8 +1306,8 @@ class WidgetsManager(Iterable):
         :type image_fit: ImageFitValue
         :return: Card Widget
         """
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=WidgetTypes.CARD, **kwargs)
+        meta = _initiate_meta(kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         # Process the description
         if description is False or description is None:
@@ -1329,8 +1325,8 @@ class WidgetsManager(Iterable):
         })
 
         # Process the image it is linked to
-        from pykechain.models import Property2
-        if isinstance(image, Property2) and image.type == PropertyType.ATTACHMENT_VALUE:
+        from pykechain.models import Property
+        if isinstance(image, Property) and image.type == PropertyType.ATTACHMENT_VALUE:
             meta.update({
                 'customImage': "/api/v3/properties/{}/preview".format(image.id),
                 'showImageValue': CardWidgetImageValue.CUSTOM_IMAGE
@@ -1344,8 +1340,8 @@ class WidgetsManager(Iterable):
             raise IllegalArgumentError("When using the add_card_widget, 'image' must be a Property or None. Type "
                                        "is: {}".format(type(image)))
 
-        from pykechain.models import Activity2
-        if isinstance(link, Activity2):
+        from pykechain.models import Activity
+        if isinstance(link, Activity):
             if link.activity_type == ActivityType.TASK:
                 default_link_value = CardWidgetLinkValue.TASK_LINK
             else:
@@ -1394,11 +1390,10 @@ class WidgetsManager(Iterable):
         return widget
 
     def add_weather_widget(self,
-                           weather_property: 'Property2',
+                           weather_property: 'Property',
                            autofill: Optional[bool] = None,
                            title: Optional[Union[bool, Text]] = False,
                            parent_widget: Optional[Union[Widget, Text]] = None,
-
                            **kwargs) -> Widget:
         """
         Add a KE-chain Weather widget to the Widgetmanager and the activity.
@@ -1406,7 +1401,7 @@ class WidgetsManager(Iterable):
         The widget will be saved in KE-chain.
 
         :param weather_property: KE-chain Weather property to display
-        :type weather_property: Property2
+        :type weather_property: Property
         :param title: A custom title for the script widget
             * False (default): Script name
             * String value: Custom title
@@ -1418,10 +1413,9 @@ class WidgetsManager(Iterable):
         :raises IllegalArgumentError: when incorrect arguments are provided
         :raises APIError: When the widget could not be created.
         """
-        weather_property = _retrieve_object(weather_property,
-                                            method=self._client.property)  # type: 'Property2'  # noqa
-        meta = _initiate_meta(kwargs, activity=self._activity_id)
-        meta, title = _set_title(meta, title=title, default_title=weather_property.name, **kwargs)
+        weather_property = _retrieve_object(weather_property, method=self._client.property)  # type: 'Property'  # noqa
+        meta = _initiate_meta(kwargs, activity=self.activity)
+        meta, title = _set_title(meta, title=title, **kwargs)
 
         meta.update({
             "propertyInstanceId": weather_property.id,
