@@ -5,7 +5,7 @@ import pytest
 
 from pykechain.enums import Multiplicity, Category, Classification, PropertyType
 from pykechain.exceptions import NotFoundError, MultipleFoundError, APIError, IllegalArgumentError
-from pykechain.models import PartSet, Part2
+from pykechain.models import PartSet, Part
 from tests.classes import TestBetamax
 from tests.utils import TEST_FLAG_IS_PIM3
 
@@ -26,7 +26,7 @@ class TestParts(TestBetamax):
 
         # Check if there are parts
         self.assertTrue(len(parts))
-        self.assertIsInstance(parts[0], Part2)
+        self.assertIsInstance(parts[0], Part)
 
     def test_retrieve_single_part(self):
         part_to_retrieve = self.project.parts()[0]
@@ -222,21 +222,21 @@ class TestParts(TestBetamax):
 
     # version 1.1.3 and later
     def test_retrieve_parent_of_part(self):
-        frame = self.project.part('Frame')  # type: Part2
+        frame = self.project.part('Frame')  # type: Part
         self.assertTrue(hasattr(frame, 'parent_id'))
         parent_of_frame = frame.parent()
         self.assertIsInstance(parent_of_frame, type(frame))
 
     def test_retrieve_children_of_part(self):
-        bike = self.project.part('Bike')  # type: Part2
-        self.assertIsInstance(bike, Part2)
+        bike = self.project.part('Bike')  # type: Part
+        self.assertIsInstance(bike, Part)
         children_of_bike = bike.children()
         self.assertIsInstance(children_of_bike, (PartSet, list))
         self.assertTrue(len(children_of_bike) >= 1)  # eg. Wheels ...
 
     def test_retrieve_siblings_of_part(self):
         """Test if the siblings of a part is the same as the children of the parent of the part"""
-        frame = self.project.part('Frame')  # type: Part2
+        frame = self.project.part('Frame')  # type: Part
         siblings_of_frame = frame.siblings()
         self.assertIsInstance(siblings_of_frame, PartSet)
         self.assertTrue(len(siblings_of_frame) >= 1)  # eg. Wheels ...
@@ -347,6 +347,17 @@ class TestParts(TestBetamax):
 
         self.assertEqual(front_fork_model.id, front_fork_retrieved_model.id)
 
+    def test_count_instances(self):
+        front_fork_model = self.project.model("Wheel")
+        nr = front_fork_model.count_instances()
+
+        self.assertIsInstance(nr, int)
+        self.assertEqual(2, nr)
+
+        bike_part = self.project.part("Bike")
+        with self.assertRaises(IllegalArgumentError):
+            bike_part.count_instances()
+
     def test_retrieve_catalog_model_of_proxy(self):
         catalog_container = self.project.model(name__startswith='Catalog')
         bearing_catalog_model = catalog_container.add_model('Bearing', multiplicity=Multiplicity.ZERO_MANY)
@@ -408,15 +419,15 @@ class TestParts(TestBetamax):
 
     # new in 1.12
     def test_retrieve_children_of_part_with_additional_arguments(self):
-        bike = self.project.part('Bike')  # type: Part2
-        self.assertIsInstance(bike, Part2)
+        bike = self.project.part('Bike')  # type: Part
+        self.assertIsInstance(bike, Part)
         children_of_bike = bike.children(name__icontains='Wheel')
         self.assertIsInstance(children_of_bike, PartSet)
         self.assertTrue(len(children_of_bike) >= 1)  # eg. Wheels ...
 
     def test_retrieve_siblings_of_part_with_additional_arguments(self):
         """Test if the siblings of a part is the same as the children of the parent of the part"""
-        frame = self.project.part('Frame')  # type: Part2
+        frame = self.project.part('Frame')  # type: Part
         siblings_of_frame = frame.siblings(name__icontains='Wheel')
         self.assertIsInstance(siblings_of_frame, PartSet)
         self.assertTrue(len(siblings_of_frame) >= 1)  # eg. Wheels ...
