@@ -2,8 +2,9 @@ import datetime
 
 from pykechain.enums import ScopeStatus, KEChainPages, ScopeMemberActions, ScopeRoles
 from pykechain.exceptions import NotFoundError, MultipleFoundError, IllegalArgumentError
-from pykechain.models import Team, Scope2
+from pykechain.models import Team, Scope
 from pykechain.models.sidebar.sidebar_manager import SideBarManager
+from pykechain.utils import is_url
 from tests.classes import TestBetamax
 
 
@@ -33,7 +34,7 @@ class TestScopes(TestBetamax):
         scope = self.client.scope(ref=scope_ref)
 
         # testing
-        self.assertIsInstance(scope, Scope2)
+        self.assertIsInstance(scope, Scope)
         self.assertTrue(scope.name, scope_name)
 
     def test_retrieve_scope_with_kwargs(self):
@@ -299,3 +300,14 @@ class TestScopeEdit(TestBetamax):
         for task in tasks:
             with self.subTest(msg=task):
                 self.scope.set_landing_page(activity=task)
+
+    def test_get_landing_page(self):
+        landing_page = self.scope.get_landing_page_url()
+
+        self.assertIsNone(landing_page)
+
+        self.scope.set_landing_page(activity=self.scope.activities()[0])
+        landing_page = self.scope.get_landing_page_url()
+
+        self.assertIsInstance(landing_page, str)
+        self.assertTrue(is_url(self.client.api_root + landing_page))
